@@ -25,7 +25,6 @@
 #include "k3bprocess.h"
 #include "k3bcore.h"
 #include "k3bversion.h"
-#include "k3bglobals.h"
 #include "k3bfilesplitter.h"
 #include "k3bisooptions.h"
 #include "k3b_i18n.h"
@@ -35,13 +34,13 @@
 #include <KIOCore/KIO/Job>
 #include <KCoreAddons/KStringHandler>
 
-#include <QtCore/QDebug>
-#include <QtCore/QDir>
-#include <QtCore/QFile>
-#include <QtCore/QRegExp>
-#include <QtCore/QStandardPaths>
-#include <QtCore/QTemporaryFile>
-#include <QtWidgets/QApplication>
+#include <QDebug>
+#include <QDir>
+#include <QFile>
+#include <QRegExp>
+#include <QStandardPaths>
+#include <QTemporaryFile>
+#include <QApplication>
 
 #include <sys/types.h>
 #include <sys/stat.h>
