@@ -17,7 +17,7 @@
 
 #include "k3bmetaitemmodel.h"
 
-#include <QtCore/QUrl>
+#include <QUrl>
 
 class KFileItem;
 
@@ -35,7 +35,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        PlacesModel( QObject* parent = 0 );
+        explicit PlacesModel( QObject* parent = 0 );
         ~PlacesModel();
 
         /**
