@@ -17,7 +17,7 @@
 #ifndef K3B_DEVICE_OPTIONTAB_H
 #define K3B_DEVICE_OPTIONTAB_H
 
-#include <QtWidgets/QWidget>
+#include <QWidget>
 
 namespace K3b {
     class DeviceWidget;
@@ -27,7 +27,7 @@ namespace K3b {
         Q_OBJECT
 
     public:
-        DeviceOptionTab( QWidget* = 0 );
+        explicit DeviceOptionTab( QWidget* = 0 );
         ~DeviceOptionTab();
 
         void readDevices();
