@@ -24,37 +24,38 @@
 #include "k3bmsf.h"
 #include "k3bmediacache.h"
 #include "k3baction.h"
+#include "k3bthememanager.h"
 
 #include <KConfigWidgets/KColorScheme>
 #include <KConfigCore/KConfigGroup>
 #include <KConfigCore/KSharedConfig>
-#include <KI18n/KLocalizedString>
+#include <KLocalizedString>
 #include <KIOCore/KIO/Global>
 #include <KWidgetsAddons/KMessageBox>
 
-#include <QtCore/QDebug>
-#include <QtCore/QEvent>
-#include <QtCore/QLocale>
-#include <QtCore/QRect>
-#include <QtCore/QTimer>
-#include <QtGui/QBrush>
-#include <QtGui/QColor>
-#include <QtGui/QFont>
-#include <QtGui/QFontMetrics>
-#include <QtGui/QMouseEvent>
-#include <QtGui/QPainter>
-#include <QtGui/QPaintEvent>
-#include <QtGui/QPixmap>
-#include <QtGui/QValidator>
-#include <QtWidgets/QFrame>
-#include <QtWidgets/QHBoxLayout>
-#include <QtWidgets/QInputDialog>
-#include <QtWidgets/QMenu>
-#include <QtWidgets/QStyle>
-#include <QtWidgets/QStyleOptionProgressBarV2>
-#include <QtWidgets/QToolButton>
-#include <QtWidgets/QToolTip>
-#include <QtWidgets/QWhatsThis>
+#include <QDebug>
+#include <QEvent>
+#include <QLocale>
+#include <QRect>
+#include <QTimer>
+#include <QBrush>
+#include <QColor>
+#include <QFont>
+#include <QFontMetrics>
+#include <QMouseEvent>
+#include <QPainter>
+#include <QPaintEvent>
+#include <QPixmap>
+#include <QValidator>
+#include <QFrame>
+#include <QHBoxLayout>
+#include <QInputDialog>
+#include <QMenu>
+#include <QStyle>
+#include <QStyleOptionProgressBarV2>
+#include <QToolButton>
+#include <QToolTip>
+#include <QWhatsThis>
 
 
 class K3b::FillStatusDisplayWidget::Private
@@ -144,7 +145,10 @@ void K3b::FillStatusDisplayWidget::paintEvent( QPaintEvent* )
         fillBrush = KColorScheme( colorGroup, KColorScheme::Selection ).background( KColorScheme::NeutralBackground );
     }
 
-    const QPen normalPen = KColorScheme( colorGroup, KColorScheme::Window ).foreground( KColorScheme::NormalText ).color();
+    QPen normalPen = KColorScheme(colorGroup, KColorScheme::Window).foreground(KColorScheme::NormalText).color();
+    if (K3b::Theme* theme = k3bappcore->themeManager()->currentTheme()) {
+        normalPen.setColor(theme->foregroundColor());
+    }
     const QPen fillPen = KColorScheme( colorGroup, KColorScheme::Selection ).foreground( KColorScheme::NormalText ).color();
 
     QStyleOptionProgressBarV2 sopb;
