@@ -15,8 +15,8 @@
 #ifndef K3B_K3BVCDTRACKKEYSDELEGATE_H
 #define K3B_K3BVCDTRACKKEYSDELEGATE_H
 
-#include <QtCore/QList>
-#include <QtWidgets/QStyledItemDelegate>
+#include <QList>
+#include <QStyledItemDelegate>
 
 
 namespace K3b {
@@ -26,7 +26,7 @@ class VcdTrack;
 class VcdTrackKeysDelegate : public QStyledItemDelegate
 {
 public:
-    VcdTrackKeysDelegate( QList<VcdTrack*>& tracks, QObject* parent = 0 );
+    explicit VcdTrackKeysDelegate( QList<VcdTrack*>& tracks, QObject* parent = 0 );
     ~VcdTrackKeysDelegate();
     
     virtual QWidget* createEditor( QWidget* parent, const QStyleOptionViewItem& option, const QModelIndex& index ) const;
